consent

package
v0.0.0-...-0149ed5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the consent type in the database.
	Label = "consent"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldClientID holds the string denoting the client_id field in the database.
	FieldClientID = "client_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// Table holds the table name of the consent in the database.
	Table = "consents"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "consents"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
)

Variables

Columns holds all SQL columns for consent fields.

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)

Functions

func And

func And(predicates ...predicate.Consent) predicate.Consent

And groups predicates with the AND operator between them.

func ClientID

func ClientID(v typedef.ClientID) predicate.Consent

ClientID applies equality check predicate on the "client_id" field. It's identical to ClientIDEQ.

func ClientIDContains

func ClientIDContains(v typedef.ClientID) predicate.Consent

ClientIDContains applies the Contains predicate on the "client_id" field.

func ClientIDContainsFold

func ClientIDContainsFold(v typedef.ClientID) predicate.Consent

ClientIDContainsFold applies the ContainsFold predicate on the "client_id" field.

func ClientIDEQ

func ClientIDEQ(v typedef.ClientID) predicate.Consent

ClientIDEQ applies the EQ predicate on the "client_id" field.

func ClientIDEqualFold

func ClientIDEqualFold(v typedef.ClientID) predicate.Consent

ClientIDEqualFold applies the EqualFold predicate on the "client_id" field.

func ClientIDGT

func ClientIDGT(v typedef.ClientID) predicate.Consent

ClientIDGT applies the GT predicate on the "client_id" field.

func ClientIDGTE

func ClientIDGTE(v typedef.ClientID) predicate.Consent

ClientIDGTE applies the GTE predicate on the "client_id" field.

func ClientIDHasPrefix

func ClientIDHasPrefix(v typedef.ClientID) predicate.Consent

ClientIDHasPrefix applies the HasPrefix predicate on the "client_id" field.

func ClientIDHasSuffix

func ClientIDHasSuffix(v typedef.ClientID) predicate.Consent

ClientIDHasSuffix applies the HasSuffix predicate on the "client_id" field.

func ClientIDIn

func ClientIDIn(vs ...typedef.ClientID) predicate.Consent

ClientIDIn applies the In predicate on the "client_id" field.

func ClientIDLT

func ClientIDLT(v typedef.ClientID) predicate.Consent

ClientIDLT applies the LT predicate on the "client_id" field.

func ClientIDLTE

func ClientIDLTE(v typedef.ClientID) predicate.Consent

ClientIDLTE applies the LTE predicate on the "client_id" field.

func ClientIDNEQ

func ClientIDNEQ(v typedef.ClientID) predicate.Consent

ClientIDNEQ applies the NEQ predicate on the "client_id" field.

func ClientIDNotIn

func ClientIDNotIn(vs ...typedef.ClientID) predicate.Consent

ClientIDNotIn applies the NotIn predicate on the "client_id" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Consent

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Consent

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Consent

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Consent

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Consent

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Consent

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Consent

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Consent

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Consent

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasUser

func HasUser() predicate.Consent

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.Consent

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...typedef.ConsentID) predicate.Consent

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...typedef.ConsentID) predicate.Consent

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Consent) predicate.Consent

Or groups predicates with the OR operator between them.

func UserID

func UserID(v typedef.UserID) predicate.Consent

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v typedef.UserID) predicate.Consent

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...typedef.UserID) predicate.Consent

UserIDIn applies the In predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v typedef.UserID) predicate.Consent

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...typedef.UserID) predicate.Consent

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Consent queries.

func ByClientID

func ByClientID(opts ...sql.OrderTermOption) OrderOption

ByClientID orders the results by the client_id field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to