redirecturi

package
v0.0.0-...-0149ed5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the redirecturi type in the database.
	Label = "redirect_uri"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldURI holds the string denoting the uri field in the database.
	FieldURI = "uri"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldModifiedAt holds the string denoting the modified_at field in the database.
	FieldModifiedAt = "modified_at"
	// FieldRelyingPartyID holds the string denoting the relying_party_id field in the database.
	FieldRelyingPartyID = "relying_party_id"
	// EdgeRelyingParty holds the string denoting the relying_party edge name in mutations.
	EdgeRelyingParty = "relying_party"
	// Table holds the table name of the redirecturi in the database.
	Table = "redirect_uris"
	// RelyingPartyTable is the table that holds the relying_party relation/edge.
	RelyingPartyTable = "redirect_uris"
	// RelyingPartyInverseTable is the table name for the RelyingParty entity.
	// It exists in this package in order to avoid circular dependency with the "relyingparty" package.
	RelyingPartyInverseTable = "relying_parties"
	// RelyingPartyColumn is the table column denoting the relying_party relation/edge.
	RelyingPartyColumn = "relying_party_id"
)

Variables

var (
	// URIValidator is a validator for the "uri" field. It is called by the builders before save.
	URIValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultModifiedAt holds the default value on creation for the "modified_at" field.
	DefaultModifiedAt func() time.Time
	// UpdateDefaultModifiedAt holds the default value on update for the "modified_at" field.
	UpdateDefaultModifiedAt func() time.Time
)

Columns holds all SQL columns for redirecturi fields.

Functions

func And

func And(predicates ...predicate.RedirectURI) predicate.RedirectURI

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.RedirectURI

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.RedirectURI

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.RedirectURI

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.RedirectURI

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.RedirectURI

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.RedirectURI

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.RedirectURI

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.RedirectURI

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.RedirectURI

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasRelyingParty

func HasRelyingParty() predicate.RedirectURI

HasRelyingParty applies the HasEdge predicate on the "relying_party" edge.

func HasRelyingPartyWith

func HasRelyingPartyWith(preds ...predicate.RelyingParty) predicate.RedirectURI

HasRelyingPartyWith applies the HasEdge predicate on the "relying_party" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

IDNotIn applies the NotIn predicate on the ID field.

func ModifiedAt

func ModifiedAt(v time.Time) predicate.RedirectURI

ModifiedAt applies equality check predicate on the "modified_at" field. It's identical to ModifiedAtEQ.

func ModifiedAtEQ

func ModifiedAtEQ(v time.Time) predicate.RedirectURI

ModifiedAtEQ applies the EQ predicate on the "modified_at" field.

func ModifiedAtGT

func ModifiedAtGT(v time.Time) predicate.RedirectURI

ModifiedAtGT applies the GT predicate on the "modified_at" field.

func ModifiedAtGTE

func ModifiedAtGTE(v time.Time) predicate.RedirectURI

ModifiedAtGTE applies the GTE predicate on the "modified_at" field.

func ModifiedAtIn

func ModifiedAtIn(vs ...time.Time) predicate.RedirectURI

ModifiedAtIn applies the In predicate on the "modified_at" field.

func ModifiedAtLT

func ModifiedAtLT(v time.Time) predicate.RedirectURI

ModifiedAtLT applies the LT predicate on the "modified_at" field.

func ModifiedAtLTE

func ModifiedAtLTE(v time.Time) predicate.RedirectURI

ModifiedAtLTE applies the LTE predicate on the "modified_at" field.

func ModifiedAtNEQ

func ModifiedAtNEQ(v time.Time) predicate.RedirectURI

ModifiedAtNEQ applies the NEQ predicate on the "modified_at" field.

func ModifiedAtNotIn

func ModifiedAtNotIn(vs ...time.Time) predicate.RedirectURI

ModifiedAtNotIn applies the NotIn predicate on the "modified_at" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.RedirectURI) predicate.RedirectURI

Or groups predicates with the OR operator between them.

func RelyingPartyID

func RelyingPartyID(v typedef.RelyingPartyID) predicate.RedirectURI

RelyingPartyID applies equality check predicate on the "relying_party_id" field. It's identical to RelyingPartyIDEQ.

func RelyingPartyIDEQ

func RelyingPartyIDEQ(v typedef.RelyingPartyID) predicate.RedirectURI

RelyingPartyIDEQ applies the EQ predicate on the "relying_party_id" field.

func RelyingPartyIDIn

func RelyingPartyIDIn(vs ...typedef.RelyingPartyID) predicate.RedirectURI

RelyingPartyIDIn applies the In predicate on the "relying_party_id" field.

func RelyingPartyIDNEQ

func RelyingPartyIDNEQ(v typedef.RelyingPartyID) predicate.RedirectURI

RelyingPartyIDNEQ applies the NEQ predicate on the "relying_party_id" field.

func RelyingPartyIDNotIn

func RelyingPartyIDNotIn(vs ...typedef.RelyingPartyID) predicate.RedirectURI

RelyingPartyIDNotIn applies the NotIn predicate on the "relying_party_id" field.

func URI

URI applies equality check predicate on the "uri" field. It's identical to URIEQ.

func URIContains

func URIContains(v string) predicate.RedirectURI

URIContains applies the Contains predicate on the "uri" field.

func URIContainsFold

func URIContainsFold(v string) predicate.RedirectURI

URIContainsFold applies the ContainsFold predicate on the "uri" field.

func URIEQ

func URIEQ(v string) predicate.RedirectURI

URIEQ applies the EQ predicate on the "uri" field.

func URIEqualFold

func URIEqualFold(v string) predicate.RedirectURI

URIEqualFold applies the EqualFold predicate on the "uri" field.

func URIGT

func URIGT(v string) predicate.RedirectURI

URIGT applies the GT predicate on the "uri" field.

func URIGTE

func URIGTE(v string) predicate.RedirectURI

URIGTE applies the GTE predicate on the "uri" field.

func URIHasPrefix

func URIHasPrefix(v string) predicate.RedirectURI

URIHasPrefix applies the HasPrefix predicate on the "uri" field.

func URIHasSuffix

func URIHasSuffix(v string) predicate.RedirectURI

URIHasSuffix applies the HasSuffix predicate on the "uri" field.

func URIIn

func URIIn(vs ...string) predicate.RedirectURI

URIIn applies the In predicate on the "uri" field.

func URILT

func URILT(v string) predicate.RedirectURI

URILT applies the LT predicate on the "uri" field.

func URILTE

func URILTE(v string) predicate.RedirectURI

URILTE applies the LTE predicate on the "uri" field.

func URINEQ

func URINEQ(v string) predicate.RedirectURI

URINEQ applies the NEQ predicate on the "uri" field.

func URINotIn

func URINotIn(vs ...string) predicate.RedirectURI

URINotIn applies the NotIn predicate on the "uri" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the RedirectURI queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByModifiedAt

func ByModifiedAt(opts ...sql.OrderTermOption) OrderOption

ByModifiedAt orders the results by the modified_at field.

func ByRelyingPartyField

func ByRelyingPartyField(field string, opts ...sql.OrderTermOption) OrderOption

ByRelyingPartyField orders the results by relying_party field.

func ByRelyingPartyID

func ByRelyingPartyID(opts ...sql.OrderTermOption) OrderOption

ByRelyingPartyID orders the results by the relying_party_id field.

func ByURI

func ByURI(opts ...sql.OrderTermOption) OrderOption

ByURI orders the results by the uri field.

Jump to