user

package
v0.0.0-...-0149ed5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldPassword holds the string denoting the password field in the database.
	FieldPassword = "password"
	// FieldTotpSecret holds the string denoting the totp_secret field in the database.
	FieldTotpSecret = "totp_secret"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldModifiedAt holds the string denoting the modified_at field in the database.
	FieldModifiedAt = "modified_at"
	// EdgeConsents holds the string denoting the consents edge name in mutations.
	EdgeConsents = "consents"
	// Table holds the table name of the user in the database.
	Table = "users"
	// ConsentsTable is the table that holds the consents relation/edge.
	ConsentsTable = "consents"
	// ConsentsInverseTable is the table name for the Consent entity.
	// It exists in this package in order to avoid circular dependency with the "consent" package.
	ConsentsInverseTable = "consents"
	// ConsentsColumn is the table column denoting the consents relation/edge.
	ConsentsColumn = "user_id"
)

Variables

var (
	Hooks [1]ent.Hook
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// PasswordValidator is a validator for the "password" field. It is called by the builders before save.
	PasswordValidator func(string) error
	// TotpSecretValidator is a validator for the "totp_secret" field. It is called by the builders before save.
	TotpSecretValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultModifiedAt holds the default value on creation for the "modified_at" field.
	DefaultModifiedAt func() time.Time
	// UpdateDefaultModifiedAt holds the default value on update for the "modified_at" field.
	UpdateDefaultModifiedAt func() time.Time
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/42milez/go-oidc-expt/pkg/ent/ent/runtime"

Columns holds all SQL columns for user fields.

Functions

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.User

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.User

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.User

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.User

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.User

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.User

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.User

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.User

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.User

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasConsents

func HasConsents() predicate.User

HasConsents applies the HasEdge predicate on the "consents" edge.

func HasConsentsWith

func HasConsentsWith(preds ...predicate.Consent) predicate.User

HasConsentsWith applies the HasEdge predicate on the "consents" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id typedef.UserID) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id typedef.UserID) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id typedef.UserID) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...typedef.UserID) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id typedef.UserID) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id typedef.UserID) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id typedef.UserID) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...typedef.UserID) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func ModifiedAt

func ModifiedAt(v time.Time) predicate.User

ModifiedAt applies equality check predicate on the "modified_at" field. It's identical to ModifiedAtEQ.

func ModifiedAtEQ

func ModifiedAtEQ(v time.Time) predicate.User

ModifiedAtEQ applies the EQ predicate on the "modified_at" field.

func ModifiedAtGT

func ModifiedAtGT(v time.Time) predicate.User

ModifiedAtGT applies the GT predicate on the "modified_at" field.

func ModifiedAtGTE

func ModifiedAtGTE(v time.Time) predicate.User

ModifiedAtGTE applies the GTE predicate on the "modified_at" field.

func ModifiedAtIn

func ModifiedAtIn(vs ...time.Time) predicate.User

ModifiedAtIn applies the In predicate on the "modified_at" field.

func ModifiedAtLT

func ModifiedAtLT(v time.Time) predicate.User

ModifiedAtLT applies the LT predicate on the "modified_at" field.

func ModifiedAtLTE

func ModifiedAtLTE(v time.Time) predicate.User

ModifiedAtLTE applies the LTE predicate on the "modified_at" field.

func ModifiedAtNEQ

func ModifiedAtNEQ(v time.Time) predicate.User

ModifiedAtNEQ applies the NEQ predicate on the "modified_at" field.

func ModifiedAtNotIn

func ModifiedAtNotIn(vs ...time.Time) predicate.User

ModifiedAtNotIn applies the NotIn predicate on the "modified_at" field.

func Name

func Name(v string) predicate.User

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.User

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.User

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.User

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.User

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.User

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.User

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.User

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.User

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.User

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.User

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.User

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.User

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.User

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func Password

func Password(v string) predicate.User

Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.

func PasswordContains

func PasswordContains(v string) predicate.User

PasswordContains applies the Contains predicate on the "password" field.

func PasswordContainsFold

func PasswordContainsFold(v string) predicate.User

PasswordContainsFold applies the ContainsFold predicate on the "password" field.

func PasswordEQ

func PasswordEQ(v string) predicate.User

PasswordEQ applies the EQ predicate on the "password" field.

func PasswordEqualFold

func PasswordEqualFold(v string) predicate.User

PasswordEqualFold applies the EqualFold predicate on the "password" field.

func PasswordGT

func PasswordGT(v string) predicate.User

PasswordGT applies the GT predicate on the "password" field.

func PasswordGTE

func PasswordGTE(v string) predicate.User

PasswordGTE applies the GTE predicate on the "password" field.

func PasswordHasPrefix

func PasswordHasPrefix(v string) predicate.User

PasswordHasPrefix applies the HasPrefix predicate on the "password" field.

func PasswordHasSuffix

func PasswordHasSuffix(v string) predicate.User

PasswordHasSuffix applies the HasSuffix predicate on the "password" field.

func PasswordIn

func PasswordIn(vs ...string) predicate.User

PasswordIn applies the In predicate on the "password" field.

func PasswordLT

func PasswordLT(v string) predicate.User

PasswordLT applies the LT predicate on the "password" field.

func PasswordLTE

func PasswordLTE(v string) predicate.User

PasswordLTE applies the LTE predicate on the "password" field.

func PasswordNEQ

func PasswordNEQ(v string) predicate.User

PasswordNEQ applies the NEQ predicate on the "password" field.

func PasswordNotIn

func PasswordNotIn(vs ...string) predicate.User

PasswordNotIn applies the NotIn predicate on the "password" field.

func TotpSecret

func TotpSecret(v string) predicate.User

TotpSecret applies equality check predicate on the "totp_secret" field. It's identical to TotpSecretEQ.

func TotpSecretContains

func TotpSecretContains(v string) predicate.User

TotpSecretContains applies the Contains predicate on the "totp_secret" field.

func TotpSecretContainsFold

func TotpSecretContainsFold(v string) predicate.User

TotpSecretContainsFold applies the ContainsFold predicate on the "totp_secret" field.

func TotpSecretEQ

func TotpSecretEQ(v string) predicate.User

TotpSecretEQ applies the EQ predicate on the "totp_secret" field.

func TotpSecretEqualFold

func TotpSecretEqualFold(v string) predicate.User

TotpSecretEqualFold applies the EqualFold predicate on the "totp_secret" field.

func TotpSecretGT

func TotpSecretGT(v string) predicate.User

TotpSecretGT applies the GT predicate on the "totp_secret" field.

func TotpSecretGTE

func TotpSecretGTE(v string) predicate.User

TotpSecretGTE applies the GTE predicate on the "totp_secret" field.

func TotpSecretHasPrefix

func TotpSecretHasPrefix(v string) predicate.User

TotpSecretHasPrefix applies the HasPrefix predicate on the "totp_secret" field.

func TotpSecretHasSuffix

func TotpSecretHasSuffix(v string) predicate.User

TotpSecretHasSuffix applies the HasSuffix predicate on the "totp_secret" field.

func TotpSecretIn

func TotpSecretIn(vs ...string) predicate.User

TotpSecretIn applies the In predicate on the "totp_secret" field.

func TotpSecretIsNil

func TotpSecretIsNil() predicate.User

TotpSecretIsNil applies the IsNil predicate on the "totp_secret" field.

func TotpSecretLT

func TotpSecretLT(v string) predicate.User

TotpSecretLT applies the LT predicate on the "totp_secret" field.

func TotpSecretLTE

func TotpSecretLTE(v string) predicate.User

TotpSecretLTE applies the LTE predicate on the "totp_secret" field.

func TotpSecretNEQ

func TotpSecretNEQ(v string) predicate.User

TotpSecretNEQ applies the NEQ predicate on the "totp_secret" field.

func TotpSecretNotIn

func TotpSecretNotIn(vs ...string) predicate.User

TotpSecretNotIn applies the NotIn predicate on the "totp_secret" field.

func TotpSecretNotNil

func TotpSecretNotNil() predicate.User

TotpSecretNotNil applies the NotNil predicate on the "totp_secret" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByConsents

func ByConsents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByConsents orders the results by consents terms.

func ByConsentsCount

func ByConsentsCount(opts ...sql.OrderTermOption) OrderOption

ByConsentsCount orders the results by consents count.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByModifiedAt

func ByModifiedAt(opts ...sql.OrderTermOption) OrderOption

ByModifiedAt orders the results by the modified_at field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByPassword

func ByPassword(opts ...sql.OrderTermOption) OrderOption

ByPassword orders the results by the password field.

func ByTotpSecret

func ByTotpSecret(opts ...sql.OrderTermOption) OrderOption

ByTotpSecret orders the results by the totp_secret field.

Jump to