Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Consent) predicate.Consent
- func ClientID(v typedef.ClientID) predicate.Consent
- func ClientIDContains(v typedef.ClientID) predicate.Consent
- func ClientIDContainsFold(v typedef.ClientID) predicate.Consent
- func ClientIDEQ(v typedef.ClientID) predicate.Consent
- func ClientIDEqualFold(v typedef.ClientID) predicate.Consent
- func ClientIDGT(v typedef.ClientID) predicate.Consent
- func ClientIDGTE(v typedef.ClientID) predicate.Consent
- func ClientIDHasPrefix(v typedef.ClientID) predicate.Consent
- func ClientIDHasSuffix(v typedef.ClientID) predicate.Consent
- func ClientIDIn(vs ...typedef.ClientID) predicate.Consent
- func ClientIDLT(v typedef.ClientID) predicate.Consent
- func ClientIDLTE(v typedef.ClientID) predicate.Consent
- func ClientIDNEQ(v typedef.ClientID) predicate.Consent
- func ClientIDNotIn(vs ...typedef.ClientID) predicate.Consent
- func CreatedAt(v time.Time) predicate.Consent
- func CreatedAtEQ(v time.Time) predicate.Consent
- func CreatedAtGT(v time.Time) predicate.Consent
- func CreatedAtGTE(v time.Time) predicate.Consent
- func CreatedAtIn(vs ...time.Time) predicate.Consent
- func CreatedAtLT(v time.Time) predicate.Consent
- func CreatedAtLTE(v time.Time) predicate.Consent
- func CreatedAtNEQ(v time.Time) predicate.Consent
- func CreatedAtNotIn(vs ...time.Time) predicate.Consent
- func HasUser() predicate.Consent
- func HasUserWith(preds ...predicate.User) predicate.Consent
- func ID(id typedef.ConsentID) predicate.Consent
- func IDEQ(id typedef.ConsentID) predicate.Consent
- func IDGT(id typedef.ConsentID) predicate.Consent
- func IDGTE(id typedef.ConsentID) predicate.Consent
- func IDIn(ids ...typedef.ConsentID) predicate.Consent
- func IDLT(id typedef.ConsentID) predicate.Consent
- func IDLTE(id typedef.ConsentID) predicate.Consent
- func IDNEQ(id typedef.ConsentID) predicate.Consent
- func IDNotIn(ids ...typedef.ConsentID) predicate.Consent
- func Not(p predicate.Consent) predicate.Consent
- func Or(predicates ...predicate.Consent) predicate.Consent
- func UserID(v typedef.UserID) predicate.Consent
- func UserIDEQ(v typedef.UserID) predicate.Consent
- func UserIDIn(vs ...typedef.UserID) predicate.Consent
- func UserIDNEQ(v typedef.UserID) predicate.Consent
- func UserIDNotIn(vs ...typedef.UserID) predicate.Consent
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the consent type in the database. Label = "consent" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldClientID holds the string denoting the client_id field in the database. FieldClientID = "client_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // Table holds the table name of the consent in the database. Table = "consents" // UserTable is the table that holds the user relation/edge. UserTable = "consents" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" )
Variables ¶
var Columns = []string{ FieldID, FieldClientID, FieldCreatedAt, FieldUserID, }
Columns holds all SQL columns for consent fields.
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
Functions ¶
func ClientID ¶
ClientID applies equality check predicate on the "client_id" field. It's identical to ClientIDEQ.
func ClientIDContains ¶
ClientIDContains applies the Contains predicate on the "client_id" field.
func ClientIDContainsFold ¶
ClientIDContainsFold applies the ContainsFold predicate on the "client_id" field.
func ClientIDEQ ¶
ClientIDEQ applies the EQ predicate on the "client_id" field.
func ClientIDEqualFold ¶
ClientIDEqualFold applies the EqualFold predicate on the "client_id" field.
func ClientIDGT ¶
ClientIDGT applies the GT predicate on the "client_id" field.
func ClientIDGTE ¶
ClientIDGTE applies the GTE predicate on the "client_id" field.
func ClientIDHasPrefix ¶
ClientIDHasPrefix applies the HasPrefix predicate on the "client_id" field.
func ClientIDHasSuffix ¶
ClientIDHasSuffix applies the HasSuffix predicate on the "client_id" field.
func ClientIDIn ¶
ClientIDIn applies the In predicate on the "client_id" field.
func ClientIDLT ¶
ClientIDLT applies the LT predicate on the "client_id" field.
func ClientIDLTE ¶
ClientIDLTE applies the LTE predicate on the "client_id" field.
func ClientIDNEQ ¶
ClientIDNEQ applies the NEQ predicate on the "client_id" field.
func ClientIDNotIn ¶
ClientIDNotIn applies the NotIn predicate on the "client_id" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasUserWith ¶
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func UserID ¶
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDNotIn ¶
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Consent queries.
func ByClientID ¶
func ByClientID(opts ...sql.OrderTermOption) OrderOption
ByClientID orders the results by the client_id field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.