Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func HasConsents() predicate.User
- func HasConsentsWith(preds ...predicate.Consent) predicate.User
- func ID(id typedef.UserID) predicate.User
- func IDEQ(id typedef.UserID) predicate.User
- func IDGT(id typedef.UserID) predicate.User
- func IDGTE(id typedef.UserID) predicate.User
- func IDIn(ids ...typedef.UserID) predicate.User
- func IDLT(id typedef.UserID) predicate.User
- func IDLTE(id typedef.UserID) predicate.User
- func IDNEQ(id typedef.UserID) predicate.User
- func IDNotIn(ids ...typedef.UserID) predicate.User
- func ModifiedAt(v time.Time) predicate.User
- func ModifiedAtEQ(v time.Time) predicate.User
- func ModifiedAtGT(v time.Time) predicate.User
- func ModifiedAtGTE(v time.Time) predicate.User
- func ModifiedAtIn(vs ...time.Time) predicate.User
- func ModifiedAtLT(v time.Time) predicate.User
- func ModifiedAtLTE(v time.Time) predicate.User
- func ModifiedAtNEQ(v time.Time) predicate.User
- func ModifiedAtNotIn(vs ...time.Time) predicate.User
- func Name(v string) predicate.User
- func NameContains(v string) predicate.User
- func NameContainsFold(v string) predicate.User
- func NameEQ(v string) predicate.User
- func NameEqualFold(v string) predicate.User
- func NameGT(v string) predicate.User
- func NameGTE(v string) predicate.User
- func NameHasPrefix(v string) predicate.User
- func NameHasSuffix(v string) predicate.User
- func NameIn(vs ...string) predicate.User
- func NameLT(v string) predicate.User
- func NameLTE(v string) predicate.User
- func NameNEQ(v string) predicate.User
- func NameNotIn(vs ...string) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Password(v string) predicate.User
- func PasswordContains(v string) predicate.User
- func PasswordContainsFold(v string) predicate.User
- func PasswordEQ(v string) predicate.User
- func PasswordEqualFold(v string) predicate.User
- func PasswordGT(v string) predicate.User
- func PasswordGTE(v string) predicate.User
- func PasswordHasPrefix(v string) predicate.User
- func PasswordHasSuffix(v string) predicate.User
- func PasswordIn(vs ...string) predicate.User
- func PasswordLT(v string) predicate.User
- func PasswordLTE(v string) predicate.User
- func PasswordNEQ(v string) predicate.User
- func PasswordNotIn(vs ...string) predicate.User
- func TotpSecret(v string) predicate.User
- func TotpSecretContains(v string) predicate.User
- func TotpSecretContainsFold(v string) predicate.User
- func TotpSecretEQ(v string) predicate.User
- func TotpSecretEqualFold(v string) predicate.User
- func TotpSecretGT(v string) predicate.User
- func TotpSecretGTE(v string) predicate.User
- func TotpSecretHasPrefix(v string) predicate.User
- func TotpSecretHasSuffix(v string) predicate.User
- func TotpSecretIn(vs ...string) predicate.User
- func TotpSecretIsNil() predicate.User
- func TotpSecretLT(v string) predicate.User
- func TotpSecretLTE(v string) predicate.User
- func TotpSecretNEQ(v string) predicate.User
- func TotpSecretNotIn(vs ...string) predicate.User
- func TotpSecretNotNil() predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByConsents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByConsentsCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByModifiedAt(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByPassword(opts ...sql.OrderTermOption) OrderOption
- func ByTotpSecret(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldPassword holds the string denoting the password field in the database. FieldPassword = "password" // FieldTotpSecret holds the string denoting the totp_secret field in the database. FieldTotpSecret = "totp_secret" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldModifiedAt holds the string denoting the modified_at field in the database. FieldModifiedAt = "modified_at" // EdgeConsents holds the string denoting the consents edge name in mutations. EdgeConsents = "consents" // Table holds the table name of the user in the database. Table = "users" // ConsentsTable is the table that holds the consents relation/edge. ConsentsTable = "consents" // ConsentsInverseTable is the table name for the Consent entity. // It exists in this package in order to avoid circular dependency with the "consent" package. ConsentsInverseTable = "consents" // ConsentsColumn is the table column denoting the consents relation/edge. ConsentsColumn = "user_id" )
Variables ¶
var ( Hooks [1]ent.Hook // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // PasswordValidator is a validator for the "password" field. It is called by the builders before save. PasswordValidator func(string) error // TotpSecretValidator is a validator for the "totp_secret" field. It is called by the builders before save. TotpSecretValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultModifiedAt holds the default value on creation for the "modified_at" field. DefaultModifiedAt func() time.Time // UpdateDefaultModifiedAt holds the default value on update for the "modified_at" field. UpdateDefaultModifiedAt func() time.Time )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/42milez/go-oidc-expt/pkg/ent/ent/runtime"
var Columns = []string{ FieldID, FieldName, FieldPassword, FieldTotpSecret, FieldCreatedAt, FieldModifiedAt, }
Columns holds all SQL columns for user fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasConsents ¶
HasConsents applies the HasEdge predicate on the "consents" edge.
func HasConsentsWith ¶
HasConsentsWith applies the HasEdge predicate on the "consents" edge with a given conditions (other predicates).
func ModifiedAt ¶
ModifiedAt applies equality check predicate on the "modified_at" field. It's identical to ModifiedAtEQ.
func ModifiedAtEQ ¶
ModifiedAtEQ applies the EQ predicate on the "modified_at" field.
func ModifiedAtGT ¶
ModifiedAtGT applies the GT predicate on the "modified_at" field.
func ModifiedAtGTE ¶
ModifiedAtGTE applies the GTE predicate on the "modified_at" field.
func ModifiedAtIn ¶
ModifiedAtIn applies the In predicate on the "modified_at" field.
func ModifiedAtLT ¶
ModifiedAtLT applies the LT predicate on the "modified_at" field.
func ModifiedAtLTE ¶
ModifiedAtLTE applies the LTE predicate on the "modified_at" field.
func ModifiedAtNEQ ¶
ModifiedAtNEQ applies the NEQ predicate on the "modified_at" field.
func ModifiedAtNotIn ¶
ModifiedAtNotIn applies the NotIn predicate on the "modified_at" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Password ¶
Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.
func PasswordContains ¶
PasswordContains applies the Contains predicate on the "password" field.
func PasswordContainsFold ¶
PasswordContainsFold applies the ContainsFold predicate on the "password" field.
func PasswordEQ ¶
PasswordEQ applies the EQ predicate on the "password" field.
func PasswordEqualFold ¶
PasswordEqualFold applies the EqualFold predicate on the "password" field.
func PasswordGT ¶
PasswordGT applies the GT predicate on the "password" field.
func PasswordGTE ¶
PasswordGTE applies the GTE predicate on the "password" field.
func PasswordHasPrefix ¶
PasswordHasPrefix applies the HasPrefix predicate on the "password" field.
func PasswordHasSuffix ¶
PasswordHasSuffix applies the HasSuffix predicate on the "password" field.
func PasswordIn ¶
PasswordIn applies the In predicate on the "password" field.
func PasswordLT ¶
PasswordLT applies the LT predicate on the "password" field.
func PasswordLTE ¶
PasswordLTE applies the LTE predicate on the "password" field.
func PasswordNEQ ¶
PasswordNEQ applies the NEQ predicate on the "password" field.
func PasswordNotIn ¶
PasswordNotIn applies the NotIn predicate on the "password" field.
func TotpSecret ¶
TotpSecret applies equality check predicate on the "totp_secret" field. It's identical to TotpSecretEQ.
func TotpSecretContains ¶
TotpSecretContains applies the Contains predicate on the "totp_secret" field.
func TotpSecretContainsFold ¶
TotpSecretContainsFold applies the ContainsFold predicate on the "totp_secret" field.
func TotpSecretEQ ¶
TotpSecretEQ applies the EQ predicate on the "totp_secret" field.
func TotpSecretEqualFold ¶
TotpSecretEqualFold applies the EqualFold predicate on the "totp_secret" field.
func TotpSecretGT ¶
TotpSecretGT applies the GT predicate on the "totp_secret" field.
func TotpSecretGTE ¶
TotpSecretGTE applies the GTE predicate on the "totp_secret" field.
func TotpSecretHasPrefix ¶
TotpSecretHasPrefix applies the HasPrefix predicate on the "totp_secret" field.
func TotpSecretHasSuffix ¶
TotpSecretHasSuffix applies the HasSuffix predicate on the "totp_secret" field.
func TotpSecretIn ¶
TotpSecretIn applies the In predicate on the "totp_secret" field.
func TotpSecretIsNil ¶
TotpSecretIsNil applies the IsNil predicate on the "totp_secret" field.
func TotpSecretLT ¶
TotpSecretLT applies the LT predicate on the "totp_secret" field.
func TotpSecretLTE ¶
TotpSecretLTE applies the LTE predicate on the "totp_secret" field.
func TotpSecretNEQ ¶
TotpSecretNEQ applies the NEQ predicate on the "totp_secret" field.
func TotpSecretNotIn ¶
TotpSecretNotIn applies the NotIn predicate on the "totp_secret" field.
func TotpSecretNotNil ¶
TotpSecretNotNil applies the NotNil predicate on the "totp_secret" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByConsents ¶
func ByConsents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByConsents orders the results by consents terms.
func ByConsentsCount ¶
func ByConsentsCount(opts ...sql.OrderTermOption) OrderOption
ByConsentsCount orders the results by consents count.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByModifiedAt ¶
func ByModifiedAt(opts ...sql.OrderTermOption) OrderOption
ByModifiedAt orders the results by the modified_at field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByPassword ¶
func ByPassword(opts ...sql.OrderTermOption) OrderOption
ByPassword orders the results by the password field.
func ByTotpSecret ¶
func ByTotpSecret(opts ...sql.OrderTermOption) OrderOption
ByTotpSecret orders the results by the totp_secret field.